README
======

This cube provides the entity type ``Book`` and uses the OpenLibrary API_
to automatically fill the book's description.

Check out : `Fetching book descriptions and covers`_

.. _`Fetching book descriptions and covers` : http://www.logilab.org/blogentry/9138
.. _API : http://openlibrary.org/dev/docs/api
